@@ -125,7 +125,7 @@ class BaseExperiment:
         test_size : float = 0.01,
         stack_models : bool = True,
         random_number : int = 0,
-        path : Optional[str] = None
+        path : Optional[str] = "."
     )->None:
         r"""
 
@@ -189,10 +189,11 @@ class BaseExperiment:
         if n_classes is None and self.stratify:
             logger.info(f"Cannot perform label stratification in regression tasks. Setting stratify to False.")
             self.stratify = False
-        self.path = "." if path is None else path
+        self.path = str(self.path).replace(".",str(os.getcwd))
         if self.path[-1] == "/":
             self.path = self.path[:-1]
         
+        
         if len(X.shape) == 2:
             self.dims = X.shape[1]
         elif len(X.shape) > 2:
@@ -863,35 +864,19 @@ class BaseExperiment:
             pseudomodel = model_type(**hparams)
         self.update_log_path()
         model_metadata = self.set_model_metadata(pseudomodel, hparams)
-        del_ckpt_path = f'{self.log_path}/checkpoints/{model_type.__name__}' 
-        del_json_path = f'{self.log_path}/jsonlogs/{model_type.__name__}'
-        del_tensorboard_path = f'{self.log_path}/tensorboardlogs/{model_type.__name__}' 
         ckpt_dir = f'{self.log_path}/checkpoints/{model_type.__name__}/{model_metadata}' 
         jsonlog_dir = f'{self.log_path}/jsonlogs/{model_type.__name__}/{model_metadata}' 
         tensorboard_dir =  f'{self.log_path}/tensorboardlogs/{model_type.__name__}/{model_metadata}' 
         if version > -1:
-            del_ckpt_path = f"{del_ckpt_path}/version_{version}"
-            del_json_path = f"{del_json_path}/version_{version}"
-            del_tensorboard_path = f"{del_tensorboard_path}/version_{version}"
             ckpt_dir = f"{ckpt_dir}/version_{version}"
             jsonlog_dir = f"{jsonlog_dir}/version_{version}"
             tensorboard_dir = f"{tensorboard_dir}/version_{version}"
         
+        shutil.rmtree(path=ckpt_dir)
+        shutil.rmtree(path=jsonlog_dir)
+        shutil.rmtree(path=tensorboard_dir)
+        
 
-        success = {ckpt_dir:0, jsonlog_dir:0, tensorboard_dir:0}
-        if os.path.exists(ckpt_dir):
-            shutil.rmtree(del_ckpt_path, ignore_errors=True)
-            success.update({ckpt_dir:1})
-        if os.path.exists(jsonlog_dir):
-            shutil.rmtree(del_json_path, ignore_errors=True)
-            success.update({jsonlog_dir:1})
-        if os.path.exists(tensorboard_dir):
-            shutil.rmtree(del_tensorboard_path, ignore_errors=True)
-            success.update({tensorboard_dir:1})
-
-        for key, value in success.items():
-            if value == 0:
-                logger.info(f"There is no directory {key}")
             
     def best_ckpt_thus_far(
         self, 
